# SharedStepReferenceModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**global_id** | **int, none_type** |  | [optional] 
**name** | **str, none_type** |  | [optional] 
**entity_type_name** | **str, none_type** |  | [optional] 
**has_this_shared_step_as_step** | **bool** |  | [optional] 
**has_this_shared_step_as_precondition** | **bool** |  | [optional] 
**has_this_shared_step_as_postcondition** | **bool** |  | [optional] 
**created_by_id** | **str** |  | [optional] 
**modified_by_id** | **str, none_type** |  | [optional] 
**created_date** | **datetime, none_type** |  | [optional] 
**modified_date** | **datetime, none_type** |  | [optional] 
**state** | **str, none_type** |  | [optional] 
**priority** | [**WorkItemPriorityModel**](WorkItemPriorityModel.md) |  | [optional] 
**is_deleted** | **bool** |  | [optional] 
**version_id** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


